#
# spec file for package zhu3d
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2006 Víctor Fernández Martínez. Valencia, Spain.
# openSuse  (c) 2006 pnemec@novell.com
# Copyright (c) 2006 Pavel Nemec pnemec@suse.cz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           zhu3d
Version:        4.2.6
Release:        7.3
Summary:        OpenGL-based equation viewer and solver
License:        GPL-3.0
Group:          Productivity/Scientific/Math
Url:            https://sourceforge.net/projects/zhu3d/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Patch0:         %{name}-pri.patch
# PATCH-FIX-OPENSUSE zhu3d-no-compilation-date.patch - fix "W: file-contains-current-date"
Patch2:         %{name}-no-compilation-date.patch
# PATCH-FIX-OPENSUSE zhu3d-ppc.patch - fixes ppc build
Patch3:         zhu3d-ppc.patch 
# PATCH-FIX-UPSTREAM zhu3d-4.2.6-qt5.patch -- courtesy of gentoo
Patch4:         %{name}-4.2.6-qt5.patch
BuildRequires:  Mesa-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
%if 0%{?suse_version} >= 1220
BuildRequires:  Mesa-libGLU-devel
%endif
%if 0%{?suse_version} >= 1315
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
%else
BuildRequires:  libqt4-devel > 4.3
BuildRequires:  libqt4-sql
BuildRequires:  libqt4-x11
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
With Zhu3D you can view, animate and solve up to three functions in
3D-space in a interactive manner. In addition, you further can observe
an independent parametric system. The OpenGL-viewer supports zooming,
scaling, rotating, translating as well as filed lightning,
transparency or surface-properties.

You have up to 8 independent lights or spotlights, background
settings, miscellaneous wire-modes or global illumination
models. Pictures are rendered as png or jpg and can have an arbitrary
size. Numerical solutions of an equation-system are found with a quite
fast and reliable adaptive random search.


%prep
%setup -q
%patch -P 0
%patch -P 2 -p1
%patch -P 3 -p1
%if 0%{?suse_version} >= 1315
%patch -P 4 -p1
%endif
find . -type f -print0|xargs -0 chmod -x
sed -i 's/\r//' readme.txt license.gpl src/changelog.txt

%build
%if 0%{?suse_version} >= 1315
%qmake5 SYSDIR=%{_datadir}
%else
qmake SYSDIR=%{_datadir} QMAKE_CFLAGS_RELEASE="%{optflags}" QMAKE_CXXFLAGS_RELEASE="%{optflags}"
%endif
make %{?_smp_mflags}

%install
# Program binary
install -Dm0755 %{name} %{buildroot}%{_bindir}/%{name}

# Other program files
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a -f work system %{buildroot}%{_datadir}/%{name}

# Desktop entry
install -Dm0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop

# Desktop icon
install -Dm0644 system/icons/%{name}.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -Dm0644 system/icons/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%fdupes -s %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%doc license.gpl readme.txt src/changelog.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%{_datadir}/pixmaps/zhu3d.png

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Mar  1 2018 aloisio@gmx.com
- Added zhu3d-4.2.6-qt5.patch and enabled Qt5 build where possible
- Spec cleanup
* Sat Apr 20 2013 dmitry_r@opensuse.org
- Update to version 4.2.6
  * Removed loading of real ancient Zhu3D-files
  * Improved Makefile for compilations for newer Intel ICC
  * Improved Czech translation.
  * Cosmetic improvements/updates or typo-fixes elsewhere
  * Removed obsolete zhu2d-4.2.4-glu-link.patch (upstream)
* Sat Dec 29 2012 dvaleev@suse.com
- use label number not a name for ppc asm call.
  fixes symbol `loop' is already defined (zhu3d-ppc.patch)
* Thu Dec 27 2012 cfarrell@suse.com
- license update: GPL-3.0
  license.gpl and the vast majority of source code files in the package
  indicate that this package is GPL-3.0, not GPL-2.0
* Mon Dec 10 2012 dmitry_r@opensuse.org
- Delete KDE3 dependence
* Wed Sep 12 2012 dmitry_r@opensuse.org
- Fix RPMLINT warning "file-contains-current-date"
  * zhu3d-no-compilation-date.patch
* Wed Aug 29 2012 scorot@free.fr
- version 4.2.4
  - Fixed a very unlikely but possible memory-bug in the XML-file
    saving/loading-part
  - Fixed a very unlikely but possible memory-leak in speedit.cpp
  - Fixes for the timestamp-counter on newer platforms
  - Slightly optimized some default window positions after the 1.st
    start ever
  - Made settings-stuff more elegant throughout the code what
    shrinks the executable size too
  - Switched icons to more modern KDE4-style where this seems
    optically feasible and consistent
  - Cosmetic improvements/updates or typo-fixes elsewhere
- fix build on recent product with patch1
- spec file reformating
* Thu Apr 30 2009 tthidney@seznam.cz
- update to 4.2
  - brushed code
  - enabled more aggressive compiler-optimisations as default
  - fixed some typos and bugs
- remove zhu3d-4.1.2_LC_NUMERIC.patch
* Wed Nov 19 2008 pnemec@suse.cz
- updated to 4.1.4
* Tue Jul 29 2008 pnemec@suse.cz
- updated to 4.1.0
* Tue Mar 11 2008 pnemec@suse.cz
- updated to 4.0.0
- The legends-editor is fully featured now. You can add up to nine labels. Each of them can be positioned, coloured, enabled or resized individually
- Raised the maximum number of user-defined functions to 64
- Switched zhu-file format to XML. The new format is not backward compatible, but you still can read old formats down to version 2.8.0 from November 2006
- Added more specific error messages for file loading
- Moved debugging switch to zhu3d.pro and excluded error class from compilation when turned off. This results in faster compile time and a smaller executable
- Changed all examples to the new 4.0.0 format
- Added legend examples
- Slight code optimisations in regards to zhu-conventions
- Note that all labels are scaleable nearly as precise as a PDF whether it is done in pure OpenGL with a bit Qt4. No complicated subclassing, no funky texture tricks, no extra libs. Developers may take a look at the source and wonder how easy it can be
- Fixed a major bug which was introduced in 3.4.8, where you could not reload files after saving
- Versions >=3.4.6 lost the ability to render textures into pictures and to printer. Fixed
- Updated English and German help-files
* Fri Mar  7 2008 pnemec@suse.cz
- updated to 3.4.4
* Fri Dec 14 2007 pnemec@suse.cz
- update to 3.3.4
* Wed Feb 21 2007 pnemec@suse.cz
  [#] spec file for package zhu3d (Version 2.9.6)
---
  > # spec file for package zhu3d (Version 2.7.2)
  100,104d99
- updated to 2.9.6
  - A comment with # can appear anywhere in a function input now instead of just at the beginning
  - Added missing hyperbolic area functions (asinh, acosh, ...) to the parsers. The hyperbolic example works now as expected
  - The solver showed a wait cursor, when it was not successfull. Corrected
* Tue Jan  2 2007 pnemec@suse.cz
- updated to 2.9.2
  - Added a spreadsheet for user defined items. So you can freely define your own constants and functions as you need it. E.g you can formulate Einsteins law as the function energy(mass)=mass*c^2 now. User defined functions can have an arbitrary amount of parameters and can be nested with other functions or constants. As things can get quite complex now, it is highly recommended to look at the new examples
  - Enabled if-conditions, boolean expressions and recursions for the OpenGL parsers and user defined items
  - Added examples for simple and complex user defined items
  - Added examples for if-conditions and boolean operators
  - Added examples for recursions
  - Added menu "File/New" for a comfortable default starting point
  - Small changes in menu entries/GUI to reflect real meanings better
  - Added/updated Chinese and French html-helpfiles. Special thanks again to Yanqing and Henri Girard for maintaining these translations
  - Updated Spanish GUI/html. Special thanks again to Victor Fernandez for maintaining this translation
  - Some code clean-ups/restructuring/size reduction
  - Adaptions in the Warp-parser for enhanced "Zhu3D-compatibility"
  - Replaced the "Open" icon for a consistent KDE-like look and feel
  - The French html was ugly when shown with internal browser. Fixed
  - Some polishing/corrections in the docs and the examples
- fixed path problem in spec file, created zhu3d.pri patch to fix path
* Fri Dec  8 2006 pnemec@suse.cz
- updated to 2.9.0
  - Replaced recursive OpenGL-parser with the bytecode-version from Warp. With some additional tuning the average speed gain is between 300%%-500%%. Especially important for costly isosurfaces on slower machines
  - Raised upper limit for isosurface grid
  - The parser syntax changed slightly. E.g: 2X*SIN(XY) must be written as 2*x*sin(x*y) now
  - To stay compatible added all missing functions to the Warp-parser and introduced the $ sign for constants there
  - New parser functions are: floor(), ceil(), cot(), csc(), sec()
  - Added new functions to recursive parser, which is still in use for solving due to it's precision
  - In parameter mode the Z-grid buttons consequently are disabled now
  - Some code shrink measurements
  - Completely reworked examples for new syntax
  - Loading a zhu-file always starts with a blank viewer window now. This avoids worrying intermixing of old/new views during build up
  - Small changes in menu entries/GUI to reflect real meanings better
  - Improvements/updates for Chinese and French GUI-translation. Special thanks again to Yanqing and Henri Girard for maintaining this translations
  - Enabled the nicer Zhu3D-logo in GUI/menu entries too now
  - The combobox under "Settings/General/Language" did not retranslate it's own language entries immediately. Fixed
  - Clean ups in ./src for readability and unifications
* Wed Nov 22 2006 Pavel Nemec <pnemec@suse.cz>
- updated to 2.7.4
- Some tuning for OpenGL list handling. Especially complexer Zhu3D files may be shown a lot faster after loading now
- Added function log2() to the parsers
- Some clean ups in translation files and error messages
* Mon Nov 20 2006 Pavel Nemec <pnemec@suse.cz>
- updated to 2.7.2
- move package into science project in build.opensuse.org
* Tue Nov 14 2006 Pavel Nemec <pnemec@suse.cz>
- update to version 2.6.7
- minor changes in specfile
  icon is now installed into /usr/share/pixmaps also
* Sun Oct 15 2006 vfernandez@polinux.upv.es
- update to version 2.4
- changed the patch to fix the paths
* Fri Sep 29 2006 vfernandez@polinux.upv.es
- update to version 2.3
* Sun Sep 17 2006 vfernandez@polinux.upv.es
- update to version 2.2
- removed the patch for the spanish translation, since Zhu3D already has it
* Wed Aug 23 2006 vfernandez@polinux.upv.es
- update to version 2.1
- added spanish translation
* Wed Aug 16 2006 vfernandez@polinux.upv.es
- first build
